/**
 * Concatenates the specified fields of an object using the passed separator or a space and places the result in the specified field, returning the full object
 *
 * @param {T} data - T.
 * @param {(keyof T)[]} [fieldsToConcat] - Which fields of the object to concatenate together
 * @param {string} [resultField] - The field to store the result in
 * @param {string} [separator] - The text to separate each field's value by. Default value for separator is " "
 * @returns {T} - Returns a new Object matching T with concatenated fields from , provided by what is stored in resultField
 */
export function ConcatenateKeys(data, fieldsToConcat = [], resultField = "result", separator = " ") {
    if (typeof data === "object") {
        let newData = data;
        let textValue = "";
        fieldsToConcat.forEach((field, index) => {
            if (index > 0)
                textValue += separator + String(newData === null || newData === void 0 ? void 0 : newData[field]);
            else
                textValue += String(newData === null || newData === void 0 ? void 0 : newData[field]);
        });
        newData[resultField] = textValue;
        return newData;
    }
    return data;
}
